@@ -239,16 +239,5 @@ L<AWS::S3::Owner>
 
 L<Iterator::Paged> - on which this class is built.
 
-=head1 AUTHOR
-
-John Drago <jdrago_999@yahoo.com>
-
-=head1 LICENSE AND COPYRIGHT
-
-This software is Free software and may be used and redistributed under the same
-terms as any version of perl itself.
-
-Copyright John Drago 2011 all rights reserved.
-
 =cut
 
